@@ -121,17 +121,25 @@ urlpatterns = [
     url(r'^$', index, name='lava_dashboard'),
     url(r'^filters/$', filters_list, name='lava_dashboard_filters_list'),
     url(r'^filters/filters_names_json$', filter_name_list_json, name='filter_name_list_json'),
-    url(r'^filters/\+add$', filter_add),
-    url(r'^filters/\+add-cases-for-test-json$', filter_add_cases_for_test_json),
+    url(r'^filters/\+add$', filter_add, name='dashboard_app.views.filters.views.filter_add'),
+    url(r'^filters/\+add-cases-for-test-json$', filter_add_cases_for_test_json,
+        name='dashboard_app.views.filters.views.filter_add_cases_for_test_json'),
     url(r'^filters/\+get-tests-json$', get_tests_json),
     url(r'^filters/\+get-test-cases-json$', get_test_cases_json),
-    url(r'^filters/\+attribute-name-completion-json$', filter_attr_name_completion_json),
-    url(r'^filters/\+attribute-value-completion-json$', filter_attr_value_completion_json),
-    url(r'^filters/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)$', filter_detail),
-    url(r'^filters/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/\+edit$', filter_edit),
-    url(r'^filters/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/\+copy$', filter_copy),
-    url(r'^filters/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/\+subscribe$', filter_subscribe),
-    url(r'^filters/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/\+delete$', filter_delete),
+    url(r'^filters/\+attribute-name-completion-json$', filter_attr_name_completion_json,
+        name='dashboard_app.views.filters.views.filter_attr_name_completion_json'),
+    url(r'^filters/\+attribute-value-completion-json$', filter_attr_value_completion_json,
+        name='dashboard_app.views.filters.views.filter_attr_value_completion_json'),
+    url(r'^filters/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)$', filter_detail,
+        name='dashboard_app.views.filters.views.filter_detail'),
+    url(r'^filters/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/\+edit$', filter_edit,
+        name='dashboard_app.views.filters.views.filter_edit'),
+    url(r'^filters/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/\+copy$', filter_copy,
+        name='dashboard_app.views.filters.views.filter_copy'),
+    url(r'^filters/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/\+subscribe$', filter_subscribe,
+        name='dashboard_app.views.filters.views.filter_subscribe'),
+    url(r'^filters/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/\+delete$', filter_delete,
+        name='dashboard_app.views.filters.views.filter_delete'),
     url(r'^filters/~(?P<username>[^/]+)/(?P<name>[a-zA-Z0-9-_]+)/\+compare/(?P<tag1>[a-zA-Z0-9-_: .+]+)/(?P<tag2>[a-zA-Z0-9-_: .+]+)$',
         compare_matches),
     url(r'^my-subscriptions$', my_subscriptions, name='lava_dashboard_my_subscriptions'),
@@ -169,8 +177,10 @@ urlpatterns = [
     url(r'^streams(?P<pathname>/[a-zA-Z0-9/._-]+)bundles/(?P<content_sha1>[0-9a-z]+)/(?P<analyzer_assigned_uuid>[a-zA-Z0-9-]+)/software-context/$',
         test_run_software_context, name='lava_dashboard_test_run_software_context'),
     url(r'^streams(?P<pathname>/[a-zA-Z0-9/._-]+)test-runs/$', test_run_list, name='lava_dashboard_test_run_list'),
-    url(r'^attachment/(?P<pk>\d+)/download$', attachment_download),
-    url(r'^attachment/(?P<pk>\d+)/view$', attachment_view),
+    url(r'^attachment/(?P<pk>\d+)/download$', attachment_download,
+        name='dashboard_app.views.attachment_download'),
+    url(r'^attachment/(?P<pk>\d+)/view$', attachment_view,
+        name='dashboard_app.views.attachment_view'),
     url(r'^permalink/test-run/(?P<analyzer_assigned_uuid>[a-zA-Z0-9-]+)/$', redirect_to_test_run,
         name='lava_dashboard_redirect_to_test_run'),
     url(r'^permalink/test-run/(?P<analyzer_assigned_uuid>[a-zA-Z0-9-]+)/(?P<trailing>.*)$', redirect_to_test_run,
@@ -184,12 +194,14 @@ urlpatterns = [
     url(r'^permalink/bundle/(?P<content_sha1>[0-9a-z]+)/(?P<trailing>.*)$', redirect_to_bundle,
         name='lava_dashboard_redirect_to_bundle_trailing'),
     url(r'^image-reports/$', images_report_list, name='lava_dashboard_image_report_list'),
-    url(r'^image-reports/(?P<name>[A-Za-z0-9_-]+)$', images_report_detail),
+    url(r'^image-reports/(?P<name>[A-Za-z0-9_-]+)$', images_report_detail,
+        name='dashboard_app.views.images.image_report_detail'),
     url(r'^image-charts/$', image_report_list,
         name='lava_dashboard_image_report_report_list'),
     url(r'^image-charts/get-report-groups$', image_report_group_list,
         name='image_report_group_list'),
-    url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)$', image_report_display),
+    url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)$', image_report_display,
+        name='dashboard_app.views.image_reports.views.image_report_display'),
     url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/\+detail$', image_report_detail,
         name='image_report_detail'),
     url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/\+add-group$', image_report_add_group,
@@ -198,19 +210,23 @@ urlpatterns = [
         name='image_report_select_group'),
     url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/\+order-update$', image_report_order_update,
         name='image_report_order_update'),
-    url(r'^image-charts/\+add$', image_report_add),
+    url(r'^image-charts/\+add$', image_report_add,
+        name='dashboard_app.views.image_reports.views.image_report_add'),
     url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/\+edit$', image_report_edit),
     url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/\+delete$', image_report_delete),
     url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/\+publish$', image_report_publish),
     url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/\+unpublish$', image_report_unpublish),
-    url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)$', image_chart_detail),
-    url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/\+add$', image_chart_add),
+    url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)$', image_chart_detail,
+        name='dashboard_app.views.image_reports.views.image_chart_detail'),
+    url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/\+add$', image_chart_add,
+        name='dashboard_app.views.image_reports.views.image_chart_add'),
     url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)/\+edit$', image_chart_edit),
     url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)/\+delete$', image_chart_delete),
     url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)/\+settings-update$', image_chart_settings_update),
     url(r'^image-charts/\+filter-type-check$', image_chart_filter_type_check),
     url(r'^image-charts/\+get-chart-test$', get_chart_test_data),
-    url(r'^image-charts/\+get-group-names$', get_group_names),
+    url(r'^image-charts/\+get-group-names$', get_group_names,
+        name='dashboard_app.views.image_reports.views.get_group_names'),
     url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)/\+export$', image_chart_export),
     url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)/\+add-filter$', image_chart_filter_add),
     url(r'^image-charts/(?P<name>[a-zA-Z0-9-_]+)/(?P<id>\d+)/(?P<slug>\d+)$', image_chart_filter_detail),
