@@ -32,9 +32,10 @@ import zmq
 import zmq.auth
 from zmq.auth.thread import ThreadAuthenticator
 
+from django.core.management.base import BaseCommand
 from django.db import transaction
+from django.db.models import Q
 from django.db.utils import OperationalError, InterfaceError
-from lava_server.utils import OptArgBaseCommand as BaseCommand
 from lava_scheduler_app.models import Device, TestJob
 from lava_scheduler_app.utils import mkdir
 from lava_scheduler_app.dbutils import (
@@ -171,30 +172,40 @@ class Command(BaseCommand):
         except ValueError:
             # do not let a bad message stop the master.
             self.logger.error("Failed to parse log message, skipping: %s", msg)
-            return False
+            return
 
         try:
             scanned = yaml.load(message)
         except yaml.YAMLError:
-            # failure to scan is not an error here, it just means the message
-            # is not a result
-            scanned = None
-        # the results logger wraps the OrderedDict in a dict called results,
-        # for identification, YAML then puts that into a list of one item for
-        # each call to log.results.
-        if isinstance(scanned, list) and len(scanned) == 1:
-            if isinstance(scanned[0], dict) and 'results' in scanned[0]:
-                job = TestJob.objects.get(id=job_id)
-                ret = map_scanned_results(scanned_dict=scanned[0], job=job)
-                if not ret:
-                    self.logger.warning(
-                        "[%s] Unable to map scanned results: %s",
-                        job_id, yaml.dump(scanned[0]))
+            self.logger.error("[%s] data are not valid YAML, dropping", job_id)
+            return
+
+        # Look for "results" level
+        try:
+            message_lvl = scanned["lvl"]
+            message_msg = scanned["msg"]
+        except KeyError:
+            self.logger.error(
+                "[%s] Invalid log line, missing \"lvl\" or \"msg\" keys: %s",
+                job_id, message)
+            return
+
+        if message_lvl == "results":
+            try:
+                job = TestJob.objects.get(pk=job_id)
+            except TestJob.DoesNotExist:
+                self.logger.error("[%s] Unknown job id", job_id)
+                return
+            ret = map_scanned_results(results=message_msg, job=job)
+            if not ret:
+                self.logger.warning(
+                    "[%s] Unable to map scanned results: %s",
+                    job_id, message)
 
         # Clear filename
         if '/' in level or '/' in name:
             self.logger.error("[%s] Wrong level or name received, dropping the message", job_id)
-            return False
+            return
         filename = "%s/job-%s/pipeline/%s/%s-%s.log" % (options['output_dir'],
                                                         job_id, level.split('.')[0],
                                                         level, name)
@@ -221,6 +232,8 @@ class Command(BaseCommand):
         self.logs[job_id].last_usage = time.time()
 
         # n.b. logging here would produce a log entry for every message in every job.
+        # The format is a list of dictionaries
+        message = "- %s" % message
 
         # Write data
         f_handler = self.logs[job_id].fd
@@ -228,14 +241,12 @@ class Command(BaseCommand):
         f_handler.write('\n')
         f_handler.flush()
 
-        # FIXME: to be removed when the web UI knows how to deal with pipeline logs
         filename = os.path.join(options['output_dir'],
                                 "job-%s" % job_id,
-                                'output.txt')
+                                'output.yaml')
         with open(filename, 'a+') as f_out:
             f_out.write(message)
             f_out.write('\n')
-        return True
 
     def controler_socket(self):
         msg = self.controler.recv_multipart()
@@ -406,10 +417,8 @@ class Command(BaseCommand):
 
     def process_jobs(self, options):
         for job in TestJob.objects.filter(
-                status=TestJob.SUBMITTED,
-                is_pipeline=True,
-                actual_device__isnull=False).order_by(
-                    '-health_check', '-priority', 'submit_time', 'target_group', 'id'):
+                Q(status=TestJob.SUBMITTED) & Q(is_pipeline=True) & ~Q(actual_device=None))\
+                .order_by('-health_check', '-priority', 'submit_time', 'target_group', 'id'):
             if job.dynamic_connection:
                 # A secondary connection must be made from a dispatcher local to the host device
                 # to allow for local firewalls etc. So the secondary connection is started on the
@@ -468,7 +477,8 @@ class Command(BaseCommand):
                                 [str(worker_host.hostname),
                                  'START', str(group_job.id), self.export_definition(group_job),
                                  str(device_configuration),
-                                 str(open(options['env'], 'r').read())])
+                                 get_env_string(options['env']),
+                                 get_env_string(options['env_dut'])])
 
                 self.controler.send_multipart(
                     [str(worker_host.hostname),
@@ -622,8 +632,7 @@ class Command(BaseCommand):
 
                 # Logging socket
                 if sockets.get(self.pull_socket) == zmq.POLLIN:
-                    if not self.logging_socket(options):
-                        continue
+                    self.logging_socket(options)
 
                 # Garbage collect file handlers
                 now = time.time()
