@@ -18,11 +18,17 @@
 
 import sys
 import django
+from django import forms
 from django.conf import settings
 from django.contrib.auth.decorators import login_required
-from django.http import HttpResponseServerError, HttpResponseForbidden
+from django.core.urlresolvers import reverse
+from django.http import (
+    HttpResponseServerError,
+    HttpResponseForbidden,
+    HttpResponseRedirect
+)
 from django.shortcuts import render_to_response, render
-from django.template import loader, RequestContext
+from django.template import loader
 from django.utils.translation import ugettext_lazy as _
 from django.views.decorators.csrf import requires_csrf_token
 
@@ -31,6 +37,22 @@ from lava_server.bread_crumbs import (
     BreadCrumbTrail,
 )
 
+from lava_scheduler_app.models import ExtendedUser
+
+
+class ExtendedUserIRCForm(forms.ModelForm):
+
+    class Meta:
+        model = ExtendedUser
+        fields = ('irc_server', 'irc_handle', 'user')
+        widgets = {'user': forms.HiddenInput}
+
+    def __init__(self, *args, **kwargs):
+        super(ExtendedUserIRCForm, self).__init__(*args, **kwargs)
+
+    def save(self, commit=True, **kwargs):
+        return super(ExtendedUserIRCForm, self).save(commit=commit, **kwargs)
+
 
 @BreadCrumb(_("LAVA"))
 def index(request):
@@ -42,13 +64,26 @@ def index(request):
             parent=index)
 @login_required
 def me(request):  # pylint: disable=invalid-name
+    ExtendedUser.objects.get_or_create(user=request.user)
     data = {
+        'irc_form': ExtendedUserIRCForm(instance=request.user.extendeduser),
         'bread_crumb_trail': BreadCrumbTrail.leading_to(
             me, you=request.user.get_full_name() or request.user.username),
     }
     return render(request, 'me.html', data)
 
 
+@login_required
+def update_irc_settings(request):
+
+    extended_user = request.user.extendeduser
+    if request.method == 'POST':
+        form = ExtendedUserIRCForm(request.POST, instance=extended_user)
+        if form.is_valid():
+            extended_user = form.save()
+            return HttpResponseRedirect(reverse('lava.me'))
+
+
 @requires_csrf_token
 def server_error(request, template_name='500.html'):
     exc_type, value, _ = sys.exc_info()
@@ -59,21 +94,11 @@ def server_error(request, template_name='500.html'):
         'exception_type': exc_type,
         'exception_value': value
     }
-    if django.VERSION > (1, 8):
-        template = loader.get_template(template_name)
-        return HttpResponseServerError(template.render(context_dict, request))
-    else:
-        return render_to_response(
-            template_name, context_dict, RequestContext(request)
-        )
+    template = loader.get_template(template_name)
+    return HttpResponseServerError(template.render(context_dict, request))
 
 
 @requires_csrf_token
 def permission_error(request, template_name='403.html'):
-    if django.VERSION > (1, 8):
-        template = loader.get_template(template_name)
-        return HttpResponseForbidden(template.render({}, request))
-    else:
-        return render_to_response(
-            template_name, {}, RequestContext(request)
-        )
+    template = loader.get_template(template_name)
+    return HttpResponseForbidden(template.render({}, request))
