@@ -26,8 +26,7 @@ from django.contrib.auth.decorators import login_required
 from django.contrib.sites.models import Site
 from django.core.urlresolvers import reverse
 from django.http import HttpResponse, HttpResponseRedirect
-from django.shortcuts import render_to_response, get_object_or_404, redirect
-from django.template import RequestContext
+from django.shortcuts import render, loader, get_object_or_404, redirect
 from django.views.decorators.csrf import csrf_exempt
 
 from linaro_django_xmlrpc.models import (
@@ -140,13 +139,14 @@ def help(request, mapper, template_name="linaro_django_xmlrpc/api.html"):  # pyl
             }
             for method in system_methods
         ]}
-    return render_to_response(template_name, {
+    template = loader.get_template(template_name)
+    return HttpResponse(template.render({
         'methods': methods,
         'context_help': ['data-export'],
         'site_url': "{scheme}://{domain}".format(
             scheme=scheme,
             domain=Site.objects.get_current().domain)
-    }, RequestContext(request))
+    }, request=request))
 
 
 @login_required
@@ -157,15 +157,14 @@ def tokens(request):
     token_list = AuthToken.objects.filter(user=request.user).order_by(
         "last_used_on")
     unused = AuthToken.objects.filter(user=request.user, last_used_on__isnull=True).count()
-
-    return render_to_response(
-        "linaro_django_xmlrpc/tokens.html",
+    template = loader.get_template("linaro_django_xmlrpc/tokens.html")
+    return HttpResponse(template.render(
         {
             "token_list": token_list,
             "unused": unused,
             "context_help": ["lava-tool"],
         },
-        RequestContext(request))
+        request=request))
 
 
 @login_required
@@ -183,12 +182,12 @@ def create_token(request):
                 reverse("linaro_django_xmlrpc_tokens"))
     else:
         form = AuthTokenForm()
-    return render_to_response(
-        "linaro_django_xmlrpc/create_token.html",
+    template = loader.get_template("linaro_django_xmlrpc/create_token.html")
+    return HttpResponse(template.render(
         {
             "form": form,
         },
-        RequestContext(request))
+        request=request))
 
 
 @login_required
@@ -198,12 +197,12 @@ def delete_token(request, object_id):
         token.delete()
         return HttpResponseRedirect(
             reverse("linaro_django_xmlrpc_tokens"))
-    return render_to_response(
-        "linaro_django_xmlrpc/authtoken_confirm_delete.html",
+    template = loader.get_template("linaro_django_xmlrpc/authtoken_confirm_delete.html")
+    return HttpResponse(template.render(
         {
             'token': token,
         },
-        RequestContext(request))
+        request=request))
 
 
 @login_required
@@ -217,13 +216,13 @@ def edit_token(request, object_id):
                 reverse("linaro_django_xmlrpc_tokens"))
     else:
         form = AuthTokenForm(instance=token)
-    return render_to_response(
-        "linaro_django_xmlrpc/edit_token.html",
+    template = loader.get_template("linaro_django_xmlrpc/edit_token.html")
+    return HttpResponse(template.render(
         {
             "token": token,
             "form": form,
         },
-        RequestContext(request))
+        request=request))
 
 
 @login_required
@@ -235,10 +234,10 @@ def delete_unused_tokens(request):
         return HttpResponseRedirect(
             reverse("linaro_django_xmlrpc_tokens")
         )
-    return render_to_response(
-        "linaro_django_xmlrpc/tokens.html",
+    template = loader.get_template("linaro_django_xmlrpc/tokens.html")
+    return HttpResponse(template.render(
         {
             "token_list": token_list,
             "context_help": ["lava-tool"],
         },
-        RequestContext(request))
+        request=request))
